.. image:: https://travis-ci.org/bartTC/dpaste.png?branch=master
    :target: https://travis-ci.org/bartTC/dpaste

.. image:: https://codecov.io/github/bartTC/dpaste/coverage.svg?branch=master
    :target: https://codecov.io/github/bartTC/dpaste?branch=master

======
dpaste
======

dpaste is a Django based pastebin. It's intended to run separately but its also
possible to be installed into an existing Django project like a regular app.

You can find a live example on http://dpaste.de/

Further documentation can be found here: http://dpaste.readthedocs.org/en/latest/
